@@ -1,5 +1,5 @@
 /* This file is part of the yazpp toolkit.
- * Copyright (C) 1998-2009 Index Data and Mike Taylor
+ * Copyright (C) 1998-2010 Index Data and Mike Taylor
  * See the file LICENSE for details.
  */
 
@@ -12,7 +12,7 @@ Z_Records *Yaz_Facility_Retrieval::pack_records (Z_Server *s,
                                                  const char *resultSetName,
                                                  int start, int xnum,
                                                  Z_RecordComposition *comp,
-                                                 int *next, int *pres,
+                                                 Odr_int *next, Odr_int *pres,
                                                  Odr_oid *format)
 {
     int recno, total_length = 0, toget = xnum, dumped_records = 0;
@@ -27,7 +27,7 @@ Z_Records *Yaz_Facility_Retrieval::pack_records (Z_Server *s,
     records->u.databaseOrSurDiagnostics = reclist;
     reclist->num_records = 0;
     reclist->records = list;
-    *pres = Z_PRES_SUCCESS;
+    *pres = Z_PresentStatus_success;
     *next = 0;
 
     for (recno = start; reclist->num_records < toget; recno++)
@@ -44,7 +44,7 @@ Z_Records *Yaz_Facility_Retrieval::pack_records (Z_Server *s,
 
         if (records->which != Z_Records_DBOSD)
         {
-            *pres = Z_PRES_FAILURE;
+            *pres = Z_PresentStatus_failure;
             return records;
         }
 
@@ -65,7 +65,7 @@ Z_Records *Yaz_Facility_Retrieval::pack_records (Z_Server *s,
             /* record is small enough, really */
             if (this_length <= m_preferredMessageSize)
             {
-                *pres = Z_PRES_PARTIAL_2;
+                *pres = Z_PresentStatus_partial_2;
                 break;
             }
             if (this_length >= m_maximumRecordSize)
@@ -114,7 +114,7 @@ void Yaz_Facility_Retrieval::fetch_via_piggyback (Z_Server *s,
     Z_RecordComposition comp, *compp = 0;
     int hits = *res->resultCount;
     
-    int *nulint = (int *)odr_malloc (odr_encode(), sizeof(*nulint));
+    Odr_int *nulint = (Odr_int *)odr_malloc (odr_encode(), sizeof(*nulint));
     *nulint = 0;
     
     comp.which = Z_RecordComp_simple;
@@ -136,8 +136,9 @@ void Yaz_Facility_Retrieval::fetch_via_piggyback (Z_Server *s,
     
     if (toget && !res->records)
     {
-        res->presentStatus = (int *) odr_malloc (odr_encode(), sizeof(int));
-        *res->presentStatus = Z_PRES_SUCCESS;
+        res->presentStatus = (Odr_int *)
+            odr_malloc (odr_encode(), sizeof(Odr_int));
+        *res->presentStatus = Z_PresentStatus_success;
         res->records =
             pack_records(s, req->resultSetName, 1, toget, compp, 
                          res->nextResultSetPosition,
